@@ -30,8 +30,8 @@
 #include <jpeglib.h>
 
 #include <libtracker-common/tracker-common.h>
-
 #include <libtracker-extract/tracker-extract.h>
+#include <libtracker-sparql/tracker-sparql.h>
 
 #include "tracker-main.h"
 
@@ -54,7 +54,8 @@
 #endif /* HAVE_LIBIPTCDATA */
 
 typedef struct {
-	gchar *camera;
+	const gchar *make;
+	const gchar *model;
 	const gchar *title;
 	const gchar *orientation;
 	const gchar *copyright;
@@ -233,23 +234,6 @@ extract_jpeg (const gchar          *uri,
 		id = g_new0 (TrackerIptcData, 1);
 	}
 
-	/* Don't merge if the make is in the model */
-	if ((xd->make == NULL || xd->model == NULL) ||
-	    (xd->make && xd->model && strstr (xd->model, xd->make) == NULL)) {
-		md.camera = tracker_merge_const (" ", 2, xd->make, xd->model);
-	} else {
-		md.camera = g_strdup (xd->model);
-	}
-
-	if (!md.camera) {
-		if ((ed->make == NULL || ed->model == NULL) ||
-		    (ed->make && ed->model && strstr (ed->model, ed->make) == NULL)) {
-			md.camera = tracker_merge_const (" ", 2, ed->make, ed->model);
-		} else {
-			md.camera = g_strdup (ed->model);
-		}
-	}
-
 	md.title = tracker_coalesce_strip (4, xd->title, ed->document_name, xd->title2, xd->pdf_title);
 	md.orientation = tracker_coalesce_strip (3, xd->orientation, ed->orientation, id->image_orientation);
 	md.copyright = tracker_coalesce_strip (4, xd->copyright, xd->rights, ed->copyright, id->copyright_notice);
@@ -269,6 +253,8 @@ extract_jpeg (const gchar          *uri,
 	md.country = tracker_coalesce_strip (2, xd->country, id->country_name);
 	md.creator = tracker_coalesce_strip (3, xd->creator, id->byline, id->credit);
 	md.comment = tracker_coalesce_strip (2, comment, ed->user_comment);
+	md.make = tracker_coalesce_strip (2, xd->make, ed->make);
+	md.model = tracker_coalesce_strip (2, xd->model, ed->model);
 
 	/* Prioritize on native dimention in all cases */
 	tracker_sparql_builder_predicate (metadata, "nfo:width");
@@ -391,15 +377,36 @@ extract_jpeg (const gchar          *uri,
 	}
 	g_ptr_array_free (keywords, TRUE);
 
-	if (md.camera) {
-		tracker_sparql_builder_predicate (metadata, "nfo:device");
-		tracker_sparql_builder_object_unvalidated (metadata, md.camera);
+	if (md.make || md.model) {
+		gchar *equip_uri;
+
+		equip_uri = tracker_sparql_escape_uri_printf ("urn:equipment:%s:%s:",
+		                                              md.make ? md.make : "",
+		                                              md.model ? md.model : "");
+
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+		tracker_sparql_builder_subject_iri (preupdate, equip_uri);
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nfo:Equipment");
+
+		if (md.make) {
+			tracker_sparql_builder_predicate (preupdate, "nfo:manufacturer");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.make);
+		}
+		if (md.model) {
+			tracker_sparql_builder_predicate (preupdate, "nfo:model");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.model);
+		}
+		tracker_sparql_builder_insert_close (preupdate);
+		tracker_sparql_builder_predicate (metadata, "nfo:equipment");
+		tracker_sparql_builder_object_iri (metadata, equip_uri);
+		g_free (equip_uri);
 	}
 
-	if (md.title) {
-		tracker_sparql_builder_predicate (metadata, "nie:title");
-		tracker_sparql_builder_object_unvalidated (metadata, md.title);
-	}
+	tracker_guarantee_title_from_file (metadata,
+	                                   "nie:title",
+	                                   md.title,
+	                                   uri);
 
 	if (md.orientation) {
 		tracker_sparql_builder_predicate (metadata, "nfo:orientation");
@@ -469,10 +476,10 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_object_double (metadata, value);
 	}
 
-	if (md.date) {
-		tracker_sparql_builder_predicate (metadata, "nie:contentCreated");
-		tracker_sparql_builder_object_unvalidated (metadata, md.date);
-	}
+	tracker_guarantee_date_from_file_mtime (metadata,
+	                                        "nie:contentCreated",
+	                                        md.date,
+	                                        uri);
 
 	if (md.description) {
 		tracker_sparql_builder_predicate (metadata, "nie:description");
@@ -529,33 +536,71 @@ extract_jpeg (const gchar          *uri,
 	}
 
 	if (md.city || md.state || md.address || md.country) {
+		gchar *addruri;
+
 		tracker_sparql_builder_predicate (metadata, "mlo:location");
 
-		tracker_sparql_builder_object_blank_open (metadata);
+		tracker_sparql_builder_object_blank_open (metadata); /* GeoPoint */
 		tracker_sparql_builder_predicate (metadata, "a");
 		tracker_sparql_builder_object (metadata, "mlo:GeoPoint");
-	
+
 		if (md.address) {
 			tracker_sparql_builder_predicate (metadata, "mlo:address");
 			tracker_sparql_builder_object_unvalidated (metadata, md.address);
 		}
-	
+
 		if (md.state) {
 			tracker_sparql_builder_predicate (metadata, "mlo:state");
 			tracker_sparql_builder_object_unvalidated (metadata, md.state);
 		}
-	
+
 		if (md.city) {
 			tracker_sparql_builder_predicate (metadata, "mlo:city");
 			tracker_sparql_builder_object_unvalidated (metadata, md.city);
 		}
-	
+
 		if (md.country) {
 			tracker_sparql_builder_predicate (metadata, "mlo:country");
 			tracker_sparql_builder_object_unvalidated (metadata, md.country);
 		}
-		
-		tracker_sparql_builder_object_blank_close (metadata);
+
+		addruri = tracker_sparql_get_uuid_urn ();
+
+		tracker_sparql_builder_predicate (metadata, "mlo:asPostalAddress");
+		tracker_sparql_builder_object_iri (metadata, addruri);
+
+		tracker_sparql_builder_object_blank_close (metadata); /* GeoPoint */
+
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+		tracker_sparql_builder_subject_iri (preupdate, addruri);
+
+		g_free (addruri);
+
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
+
+		if (md.address) {
+			tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.address);
+		}
+
+		if (md.state) {
+			tracker_sparql_builder_predicate (preupdate, "nco:region");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.state);
+		}
+
+		if (md.city) {
+			tracker_sparql_builder_predicate (preupdate, "nco:locality");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.city);
+		}
+
+		if (md.country) {
+			tracker_sparql_builder_predicate (preupdate, "nco:country");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.country);
+		}
+
+		tracker_sparql_builder_insert_close (preupdate);
+
 	}
 
 	if (cinfo.density_unit != 0 || ed->x_resolution) {
@@ -598,8 +643,6 @@ extract_jpeg (const gchar          *uri,
 
 	jpeg_destroy_decompress (&cinfo);
 
-	g_free (md.camera);
-
 	tracker_exif_free (ed);
 	tracker_xmp_free (xd);
 	tracker_iptc_free (id);
